<?php

if ( !defined( "crazyblog_DIR" ) )
	die( '!!!' );

/**
 * * 
 * Duffers Custom Post Type Class
 * This class is used to help create custom post types
 * @author Aarif <arifsaroha@gmail.com>
 * @version 1.0
 */
class crazyblog_Custom_post_types {

	private static $_instance = null;

	public function init() {
		add_action( 'init', array( $this, 'crazyblog_register_post_type' ), 0 );
		$this->crazyblog_post_columns();
	}

	public function crazyblog_post_init() {
		return array(
			'crazyblog_recipe' => array(
				'labels' => array( __( 'Recipe', 'wp_crazyblog' ), __( 'Recipe\'s', 'wp_crazyblog' ) ),
				'supports' => array( 'title', 'editor', 'thumbnail', 'comments' ),
				'slug' => 'recipe',
				'args' => array( 'menu_icon' => 'dashicons-crazy-recipes2' ),
				'columns' => array( 'thumbnail' ),
				'taxonomies' => array( 'post_tag' ),
				'taxonomy' => array(
					'labels' => array( 'name' => __( 'Categories', 'crazyblog' ), 'singular_name' => __( 'Recipe Categories', 'crazyblog' ) ),
					'name' => 'recipe_category',
					'slug' => __( 'recipe_category', 'crazyblog' ),
				),
			),
			'crazyblog_gallery' => array(
				'labels' => array( __( 'Gallery', 'wp_crazyblog' ), __( 'Gallery', 'wp_crazyblog' ) ),
				'supports' => array( 'title', 'thumbnail' ),
				'slug' => 'gallery',
				'args' => array( 'menu_icon' => 'dashicons-crazy-gallery' ),
				'columns' => array( 'thumbnail' ),
				'taxonomies' => array(),
			),
			'crazyblog_forms' => array(
				'labels' => array( __( 'Form', 'advocate' ), __( 'Forms', 'advocate' ) ),
				'supports' => array( 'title' ),
				'slug' => 'form',
				'name' => __( 'Form', 'advocate' ),
				'args' => array( 'menu_icon' => 'dashicons-crazy-contract' ),
				'columns' => array( '' ),
				'taxonomies' => array(),
			),
		);
	}

	public function crazyblog_register_post_type() {
		$post_types = $this->crazyblog_post_init();
		if ( !empty( $post_types ) ):
			foreach ( $post_types as $key => $post ):
				$rewrite = array(
					'slug' => crazyblog_set( $post, 'slug' ),
					'with_front' => true,
					'pages' => true,
					'feeds' => false,
				);
				$labels = $this->labels( crazyblog_set( $post, 'labels' ) );
				$args = $this->options( array(
					'labels' => $labels,
					'supports' => crazyblog_set( $post, 'supports' ),
					'label' => crazyblog_set( crazyblog_set( $post, 'labels' ), '0' ),
					'rewrite' => $rewrite,
					'taxonomies' => crazyblog_set( $post, 'taxonomies' )
						) );
				$args = wp_parse_args( crazyblog_set( $post, 'args' ), $args );
				$register = register_post_type( $key, $args );
				if ( is_wp_error( $register ) ):
					echo $register->get_error_message();
				else:
					if ( crazyblog_set( $post, 'taxonomy' ) ):
						$taxonomy = crazyblog_set( $post, 'taxonomy' );
						$rewrite = array(
							'slug' => crazyblog_set( $taxonomy, 'slug' ),
							'with_front' => true,
							'hierarchical' => true,
						);
						$labels = $this->crazyblog_taxonomy_label( crazyblog_set( $taxonomy, 'labels' ) );
						$args = $this->crazyblog_taxonomy_options( array(
							'labels' => $labels,
							'rewrite' => $rewrite,
								) );
						register_taxonomy( crazyblog_set( $taxonomy, 'name' ), array( $key ), $args );
					endif;
				endif;
			endforeach;
		endif;
	}

	public function labels( $name = '' ) {
		$labels = array(
			'name' => _x( 'Post', 'Posts', 'wp_crazyblog' ),
			'singular_name' => _x( 'Post', 'Posts', 'wp_crazyblog' ),
			'menu_name' => __( 'Posts', 'wp_crazyblog' ),
			'name_admin_bar' => __( 'Post', 'wp_crazyblog' ),
			'parent_item_colon' => __( 'Parent Post:', 'wp_crazyblog' ),
			'all_items' => __( 'All Posts', 'wp_crazyblog' ),
			'add_new_item' => __( 'Add New Post', 'wp_crazyblog' ),
			'add_new' => __( 'Add New', 'wp_crazyblog' ),
			'new_item' => __( 'New Post', 'wp_crazyblog' ),
			'edit_item' => __( 'Edit Post', 'wp_crazyblog' ),
			'update_item' => __( 'Update Post', 'wp_crazyblog' ),
			'view_item' => __( 'View Post', 'wp_crazyblog' ),
			'search_items' => __( 'Search Post', 'wp_crazyblog' ),
			'not_found' => __( 'Not found', 'wp_crazyblog' ),
			'not_found_in_trash' => __( 'Not found in Trash', 'wp_crazyblog' ),
		);

		foreach ( $labels as $key => $val ):
			$_labels_[$key] = str_replace( array( 'Post', 'Posts' ), $name, $val );
		endforeach;

		$labels = wp_parse_args( $_labels_, $labels );
		return $_labels_;
	}

	public function options( $args = array() ) {
		$defaults = array(
			//'label' => __('post_type', 'wp_crazyblog'),
			//'description' => __('Post Type Description', 'wp_crazyblog'),
			'labels' => crazyblog_set( $args, 'labels' ),
			'supports' => array( 'title', 'editor', 'excerpt', 'author', 'thumbnail', 'comments', 'trackbacks', 'revisions', 'custom-fields', 'page-attributes', 'post-formats', ),
			'taxonomies' => array(),
			'hierarchical' => false,
			'public' => true,
			'show_ui' => true,
			'show_in_menu' => true,
			'menu_position' => 5,
			'show_in_admin_bar' => true,
			'show_in_nav_menus' => true,
			'can_export' => true,
			'has_archive' => true,
			'exclude_from_search' => false,
			'publicly_queryable' => true,
			'capability_type' => 'page',
			'rewrite' => array(),
		);
		$args = wp_parse_args( $args, $defaults );

		return $args;
	}

	public function crazyblog_taxonomy_label( $name = '' ) {
		$defaults = array(
			'name' => _x( 'Category', 'Categories', 'wp_crazyblog' ),
			'singular_name' => _x( 'Category', 'Category', 'wp_crazyblog' ),
			'menu_name' => __( 'Categories', 'wp_crazyblog' ),
			'all_items' => __( 'All Categories', 'wp_crazyblog' ),
			'parent_item' => __( 'Parent Category', 'wp_crazyblog' ),
			'parent_item_colon' => __( 'Parent Category:', 'wp_crazyblog' ),
			'new_item_name' => __( 'New Category Name', 'wp_crazyblog' ),
			'add_new_item' => __( 'Add New Category', 'wp_crazyblog' ),
			'edit_item' => __( 'Edit Category', 'wp_crazyblog' ),
			'update_item' => __( 'Update Category', 'wp_crazyblog' ),
			'separate_items_with_commas' => __( 'Separate Categories with commas', 'wp_crazyblog' ),
			'search_items' => __( 'Search Categories', 'wp_crazyblog' ),
			'add_or_remove_items' => __( 'Add or remove Categories', 'wp_crazyblog' ),
			'choose_from_most_used' => __( 'Choose from the most used Categories', 'wp_crazyblog' ),
		);
		foreach ( $defaults as $key => $val ):
			$labels[$key] = str_replace( array( 'Category', 'Categories' ), $name, $val );
		endforeach;

		$labels = wp_parse_args( $labels, $defaults );
		return $labels;
	}

	public function crazyblog_taxonomy_options( $args = array() ) {

		$default = array(
			'labels' => crazyblog_set( $args, 'labels' ),
			'hierarchical' => true,
			'public' => true,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'show_tagcloud' => true,
			'rewrite' => array(),
		);
		$args = wp_parse_args( $args, $default );
		return $args;
	}

	public function crazyblog_post_columns() {
		$post_types = $this->crazyblog_post_init();
		if ( !empty( $post_types ) ):
			foreach ( $post_types as $key => $post ):
				$columns = crazyblog_set( $post, 'columns' );
				if ( $columns && !empty( $columns ) ):
					add_filter( 'manage_' . $key . '_posts_columns', array( $this, 'crazyblog_columns_head' ) );
					add_action( 'manage_' . $key . '_posts_custom_column', array( $this, 'crazyblog_columns_content' ), 10, 2 );
					add_action( 'restrict_manage_posts', array( $this, 'crazyblog_add_taxonomy_filters' ) );
				endif;
			endforeach;
		endif;
	}

	public function crazyblog_columns_head( $defaults ) {
		$post_types = $this->crazyblog_post_init();
		if ( !empty( $post_types ) ):
			foreach ( $post_types as $key => $post ):
				$_columns = crazyblog_set( $post, 'columns' );
				foreach ( $_columns as $c ):
					$defaults[$c] = ucwords( str_replace( '_', ' ', $c ) );
				endforeach;
				unset( $defaults['date'] );
				$defaults['date'] = __( 'Date', 'wp_crazyblog' );
				return $defaults;
			endforeach;
		endif;
	}

	public function crazyblog_columns_content( $column_name, $post_ID ) {
		if ( $column_name == 'thumbnail' ):
			$post_featured_image = $this->crazyblog_get_post_image( $post_ID );
			if ( $post_featured_image ) {
				echo '<img height="50px" width="50px" src="' . $post_featured_image . '" />';
			}
		endif;
	}

	public function crazyblog_get_post_image( $post_id ) {
		$post_thumbnail_id = get_post_thumbnail_id( $post_id );
		if ( $post_thumbnail_id ) {
			$post_thumbnail_img = wp_get_attachment_image_src( $post_thumbnail_id, 'thumbnail' );
			return crazyblog_set( $post_thumbnail_img, '0' );
		}
	}

	public function crazyblog_add_taxonomy_filters() {
		global $typenow;
		global $wp_query;
		$post_types = $this->crazyblog_post_init();
		if ( !empty( $post_types ) ):
			foreach ( $post_types as $key => $post ):
				if ( crazyblog_set( $post, 'taxonomy' ) != '' ):
					if ( $typenow == $key ) {
						$tax = crazyblog_set( $post, 'taxonomy' );
						$name = crazyblog_set( $tax, 'name' );
						$label = crazyblog_set( crazyblog_set( $tax, 'labels' ), '1' );
						$args = array(
							'orderby' => 'name',
							'hide_empty' => false
						);
						$terms = get_terms( $name, $args );
						if ( $terms ) {
							printf( ' &nbsp;<select name="%s" class="postform">', $label );
							printf( '<option value="0">%s</option>', sprintf( __( 'Show all %s', 'wp_crazyblog' ), $label ) );
							foreach ( $terms as $term ) {
								if ( isset( $_GET[$tax_slug] ) && $_GET[$tax_slug] === $term->slug ) {
									printf( '<option value="%s" selected="selected">%s (%s)</option>', $term->slug, $term->name, $term->count );
								} else {
									printf( '<option value="%s">%s (%s)</option>', $term->slug, $term->name, $term->count );
								}
							}
							print( '</select>&nbsp;' );
						}
					}
				endif;
			endforeach;
		endif;
	}

	static public function get_instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

}
