<?php

/**
 * @version    $Id$
 * @package    CR MegaMenu
 * @author     Webinane Team <support@Webinane.com>
 * @copyright  Copyright (C) 2014 Webinane.com All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 *
 * Websites: http://www.Webinane.com
 * Technical Support:  Feedback - http://www.Webinane.com
 */
class CR_Megamenu_Helpers_Modal {

	private static $instance;

	public static function get_instance() {
		if ( !self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	private function __construct() {
		add_filter( 'cr_mm_register_assets', array( &$this, 'apply_assets' ) );
		$this->enqueue_assets();
	}

	/**
	 * Register custom assets to use on Modal
	 * @param array $assets
	 * @return array
	 */
	public function apply_assets( $assets ) {
		$assets['cr-megamenu-modal-css'] = array(
			'src' => '/assets/css/modal.css',
			'ver' => '1.0.0',
		);
		$assets['cr-megamenu-codemirror-css'] = array(
			'src' => '/assets/3rd-party/codemirror/codemirror.css',
			'ver' => '1.0.0',
		);
		$assets['cr-megamenu-codemirror-js'] = array(
			'src' => '/assets/3rd-party/codemirror/codemirror.js',
			'ver' => '1.0.0',
		);
		$assets['cr-megamenu-codemirrormode-css-js'] = array(
			'src' => '/assets/3rd-party/codemirror/mode/css.js',
			'ver' => '1.0.0',
		);

		$assets['cr-megamenu-placeholder'] = array(
			'src' => '/assets/Webinane/js/placeholder.js',
			'ver' => '1.0.0',
		);
		$assets['cr-customcss-css'] = array(
			'src' => '/assets/css/custom_css.css',
			'deps' => array( 'cr-mm-bootstrap3-css' ),
			'ver' => '1.0.0',
		);
		$assets['cr-custom-css-js'] = array(
			'src' => '/assets/js/custom_css.js',
			'ver' => '1.0.0',
		);

		$assets = apply_filters( 'cr_mm_assets_register_modal', $assets );

		return $assets;
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_assets() {
		CR_Megamenu_Init_Assets::load( array( 'cr-mm-bootstrap3-css', 'cr-bootstrap3-js', 'cr-joomlashine-css' ) );
		CR_Megamenu_Init_Assets::load( array( 'cr-jquery-ui-css', 'cr-megamenu-modal-css', 'cr-mm-css' ) );
		CR_Megamenu_Init_Assets::load( array( 'cr-bootstrap3-icomoon-css', 'cr-font-awesome-css', 'cr-mm-admin-css' ) );
		CR_Megamenu_Init_Assets::load( array( 'cr-jquery-ui-css', 'cr-jquery-select2-css', 'cr-jquery-select2-bootstrap3-css' ) );
		CR_Megamenu_Init_Assets::load( array( 'cr-mm-jqueryfancybox-css' ) );

		if ( function_exists( 'wp_enqueue_media' ) ) {
			wp_enqueue_media();
		} else {
			wp_enqueue_style( 'thickbox' );
			wp_enqueue_script( 'media-upload' );
			wp_enqueue_script( 'thickbox' );
		}

		$scripts = array( 'jquery', 'jquery-ui', 'jquery-ui-resizable', 'jquery-ui-sortable', 'jquery-ui-tabs', 'jquery-ui-dialog', 'jquery-ui-button', 'jquery-ui-slider', 'cr-jquery-livequery-js', 'jquery-resize-js', 'cr-joomlashine-modalresize-js', 'cr-jquery-select2-js' );

		CR_Megamenu_Init_Assets::load( $scripts );
		$scripts = array( 'cr-mm-layout-js', 'cr-mm-placeholder' );
		CR_Megamenu_Init_Assets::load( $scripts );

		// Check # review
		CR_Megamenu_Init_Assets::load( array( 'cr-mm-modal-js', 'cr-custom-css-js' ) );
		CR_Megamenu_Init_Assets::load( array( 'cr-megamenu-placeholder' ) );

		// Load element editor script
		CR_Megamenu_Init_Assets::load( 'cr-mm-handleelement-js' );

		// Load element settings script
		CR_Megamenu_Init_Assets::load( 'cr-mm-handlesetting-js' );

		// Load ZeroClipboard JavaScript library for Shortcode Content tab
		CR_Megamenu_Init_Assets::load( 'cr-zeroclipboard-js' );

		CR_Megamenu_Init_Assets::load( 'cr-mm-widget-js' );

		// Load Jquery fancybox
		CR_Megamenu_Init_Assets::load( 'cr-mm-jqueryfancybox-js' );

		// Load for element image
		CR_Megamenu_Init_Assets::load( 'cr-mm-imagefrontend-js' );

		CR_Megamenu_Init_Assets::localize( 'cr-custom-css-js', 'Cr_Megamenu_Translate', CR_Megamenu_Helpers_Functions::js_translation() );
		CR_Megamenu_Init_Assets::localize( 'cr-mm-handlesetting-js', 'Cr_Megamenu_Ajax', CR_Megamenu_Helpers_Functions::localize_js() );
		CR_Megamenu_Helpers_Functions::cr_localize();
	}

	/**
	 * Get related content for each Modal
	 * @param type $page
	 */
	public function show_modal( $page = '' ) {
		
		add_action( 'cr_megamenu_modal_page_content', array( &$this, 'content' . $page ) );
	}

	/**
	 * HTML content for Custom css Modal
	 */
	public function content_custom_css() {
		$assets = apply_filters( 'cr_mm_assets_enqueue_modal', array( 'cr-customcss-css', 'cr-megamenu-codemirror-css', 'cr-megamenu-codemirror-js', 'cr-megamenu-codemirrormode-css-js' ) );
		CR_Megamenu_Init_Assets::load( $assets );
		include CR_MEGAMENU_TPL_PATH . '/custom-css.php';
	}

	public function content_add_element() {
		include CR_MEGAMENU_TPL_PATH . '/select-elements.php';
	}

	/**
	 * HTML content for Shortcode editing Modal
	 */
	public function content() {
		// Load required assets
		$assets = apply_filters( 'cr_mm_assets_enqueue_modal', array( 'cr-mm-handlesetting-js' ) );
		CR_Megamenu_Init_Assets::load( $assets );

		include CR_MEGAMENU_TPL_PATH . '/modal.php';
	}

	/**
	 * Ignore settings key in array
	 * @param array $options
	 * @return array
	 */
	static function ignore_settings( $options ) {
		if ( array_key_exists( 'settings', $options ) ) {
			$options = array_slice( $options, 1 );
		}

		return $options;
	}

	/**
	 * Add setting data to a tag
	 * @param string $tag
	 * @param array $data
	 * @param string $content
	 * @return string
	 */
	static function tab_settings( $tag, $data, $content ) {
		$tag_data = array();
		if ( !empty( $data ) ) {
			foreach ( $data as $key => $value ) {
				if ( !empty( $value ) ) {
					$tag_data[] = "$key = '$value'";
				}
			}
		}
		$tag_data = implode( ' ', $tag_data );

		return "<$tag $tag_data>$content</$tag>";
	}

	/**
	 * get HTML of Modal Settings Box of Shortcode
	 * @param array $options
	 * @return string
	 */
	static function get_shortcode_modal_settings( $settings, $shortcode = '', $input_params = null, $raw_shortcode = null ) {
		$i = 0;
		$tabs = $contents = $actions = $general_actions = array();

		foreach ( $settings as $tab => $options ) {
			$options = self::ignore_settings( $options );
			if ( $tab == 'action' ) {
				foreach ( $options as $option ) {
					$actions[] = CR_Megamenu_Helpers_Shortcode::render_parameter( $option['type'], $option );
				}
			} else if ( $tab == 'generalaction' ) {
				foreach ( $options as $option ) {
					$option['id'] = isset( $option['id'] ) ? ( 'param-' . $option['id']) : '';
					$general_actions[] = CR_Megamenu_Helpers_Shortcode::render_parameter( $option['type'], $option );
				}
			} else {
				$active = ($i++ == 0) ? 'active' : '';
				if ( strtolower( $tab ) != 'notab' ) {
					$data_ = isset( $settings[$tab]['settings'] ) ? $settings[$tab]['settings'] : array();
					$data_['href'] = "#$tab";
					$data_['data-toggle'] = 'tab';
					$content_ = ucfirst( $tab );
					$tabs[] = "<li class='$active'>" . self::tab_settings( 'a', $data_, $content_ ) . '</li>';
				}

				$has_margin = 0;
				$param_html = array();
				foreach ( $options as $idx => $option ) {
					// check if this element has Margin param (1)
					if ( isset( $option['name'] ) && $option['name'] == __( 'Margin', CR_MEGAMENU_TEXTDOMAIN ) && $option['id'] != 'div_margin' )
						$has_margin = 1;
					// if (1), don't use the 'auto extended margin ( top, bottom ) option'
					if ( $has_margin && isset( $option['id'] ) && $option['id'] == 'div_margin' )
						continue;

					$type = $option['type'];
					$option['id'] = isset( $option['id'] ) ? ( 'param-' . $option['id']) : "$idx";
					if ( !is_array( $type ) ) {
						$param_html[$option['id']] = CR_Megamenu_Helpers_Shortcode::render_parameter( $type, $option, $input_params );
					} else {
						$output_inner = '';
						foreach ( $type as $sub_options ) {
							$sub_options['id'] = isset( $sub_options['id'] ) ? ( 'param-' . $sub_options['id'] ) : '';
							/* for sub option, auto assign bound = 0 {not wrapped by <div class='controls'></div> } */
							$sub_options['bound'] = '0';
							/* for sub option, auto assign 'input-small' class */
							$sub_options['class'] = isset( $sub_options['class'] ) ? ($sub_options['class']) : '';
							$type = $sub_options['type'];
							$output_inner .= CR_Megamenu_Helpers_Shortcode::render_parameter( $type, $sub_options );
						}
						$option = CR_Megamenu_Helpers_Html::get_extra_info( $option );
						$label = CR_Megamenu_Helpers_Html::get_label( $option );
						$param_html[$option['id']] = CR_Megamenu_Helpers_Html::final_element( $option, $output_inner, $label );
					}
				}

				if ( !empty( $param_html['param-copy_style_from'] ) ) {
					array_pop( $param_html );
					// move "auto extended margin ( top, bottom ) option" to top of output
					$style_copy = array_shift( $param_html );
					// Shift Preview frame from the array
					$preview = array_shift( $param_html );

					if ( !empty( $param_html['param-div_margin'] ) ) {
						$margin = $param_html['param-div_margin'];
						$param_html = array_merge(
								array(
							$preview,
							$style_copy,
							$margin,
								), $param_html
						);
					} else {
						$param_html = array_merge(
								array(
							$preview,
							$style_copy,
								), $param_html
						);
					}
				}

				$param_html = implode( '', $param_html );
				$content_tab = "<div class='tab-pane $active cr-mm-setting-tab' id='$tab'>$param_html</div>";
				$contents[] = $content_tab;
			}
		}

		return self::setting_tab_html( $shortcode, $tabs, $contents, $general_actions, $settings, $actions );
	}

	/**
	 * Generate tab with content, use for generating Modal
	 * @return string
	 */
	static function setting_tab_html( $shortcode, $tabs, $contents, $general_actions, $settings, $actions ) {
		$output = '<input type="hidden" value="' . $shortcode . '" id="shortcode_name" name="shortcode_name" />';

		/* Tab Content - Styling */

		$output .= '<div class="jsn-tabs">';
		if ( count( $tabs ) > 0 ) {
			$output .= '<ul class="" id="cr_option_tab">';
			$output .= implode( '', $tabs );
			$output .= '</ul>';
		}
		/* Tab Content */

		$output .= implode( '', $contents );

		$output .= "<div class='jsn-buttonbar cr_action_btn'>";

		/* Tab Content - General actions */
		if ( count( $general_actions ) ) {
			$data = $settings['generalaction']['settings'];
			$content_ = implode( '', $general_actions );
			$output .= self::tab_settings( 'div', $data_, $content_ );
		}

		$output .= implode( '', $actions );
		$output .= '</div>';
		$output .= '</div>';

		return $output;
	}

	/**
	 * Append shortcode content tab to all element settings modal.
	 * @param   array &$tabs Current tabs array.
	 * @param   array &$contents Currnt content array.
	 * @param   string $raw_shortcode Raw shortcode content.
	 * @return  void
	 */
	public static function shortcode_content_tab( &$tabs, &$contents, $raw_shortcode ) {
		// Auto-append `Shortcode Content` tab only if this is not a sub-modal
		if ( !isset( $_REQUEST['submodal'] ) || !$_REQUEST['submodal'] ) {
			// Generate tab for shortcode content
			$tabs[] = '<li><a href="#shortcode-content" data-toggle="tab">' . __( 'Shortcode', CR_MEGAMENU_TEXTDOMAIN ) . '</a></li>';

			// Generate content for shortcode content tab
			$contents[] = '<div class="tab-pane clearfix" id="shortcode-content">'
					. '<textarea id="shortcode_content" class="form-control" rows="10" disabled="disabled">' . esc_textarea( $raw_shortcode ) . '</textarea>'
					. '<div class="text-center"><button class="btn btn-success" id="copy_to_clipboard" data-textchange="' . __( 'Done!', CR_MEGAMENU_TEXTDOMAIN ) . '">' . __( 'Copy to Clipboard', CR_MEGAMENU_TEXTDOMAIN ) . '</button></div>'
					. '</div>';
		} else {
			// Generate hidden text area to hold raw shortcode
			$contents[] = '<textarea class="hidden" id="shortcode_content">' . esc_textarea( $raw_shortcode ) . '</textarea>';
		}
	}

}
