<?php

/**
 * @version    $Id$
 * @package    CR MegaMenu
 * @author     Webinane Team <support@Webinane.com>
 * @copyright  Copyright (C) 2014 Webinane.com All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 *
 * Websites: http://www.Webinane.com
 * Technical Support:  Feedback - http://www.Webinane.com
 */

/**
 * CR MegaMenu admin menu initialization.
 *
 * @package  CR_Megamenu
 * @since    1.0.0
 */
class CR_Megamenu_Admin_Menu {

	/**
	 * Define pages.
	 *
	 * @var  array
	 */
	public static $pages = array( 'cr-megamenu-settings', 'cr-menu-addons' );

	/**
	 * Initialize CR MegaMenu admin menu.
	 *
	 * @return  void
	 */
	public static function init() {
		global $pagenow;

		// Get product information
		$plugin = CR_Megamenu_Product_Info::get( CR_MEGAMENU_IDENTIFIED_NAME );

		// Generate menu title
		$menu_title = __( 'CR MegaMenu', CR_MEGAMENU_TEXTDOMAIN );

		if ( isset( $plugin['Available_Update'] ) && $plugin['Available_Update'] && ( 'admin.php' != $pagenow || !isset( $_GET['page'] ) || !in_array( $_GET['page'], self::$pages ) ) ) {
			$menu_title .= " <span class='cr-available-updates update-plugins count-{$plugin['Available_Update']}'><span class='pending-count'>{$plugin['Available_Update']}</span></span>";
		}

		$menu = array(
			'page_title' => __( $menu_title, CR_MEGAMENU_TEXTDOMAIN ),
			'menu_title' => __( 'Settings', CR_MEGAMENU_TEXTDOMAIN ),
			'capability' => 'manage_options',
			'menu_slug' => 'cr-megamenu-settings',
			'function' => array( __CLASS__, 'settings' ),
		);

		/*
		  CR_Megamenu_Init_Admin_Menu::add( $menu , 'edit.php?post_type=cr_megamenu_profile' );
		 */

		if ( @$plugin['Addons'] ) {
			// Generate menu title
			$menu_title = __( 'Add-ons', CR_MEGAMENU_TEXTDOMAIN );
			if ( @$plugin['Available_Update'] && ( 'admin.php' == $pagenow && isset( $_GET['page'] ) && in_array( $_GET['page'], self::$pages ) ) ) {
				$menu_title .= " <span class='cr-available-updates update-plugins count-{$plugin['Available_Update']}'><span class='pending-count'>{$plugin['Available_Update']}</span></span>";
			}

			// Update admin menus
			$menu = array(
				'page_title' => __( 'CR MegaMenu - Add-ons', CR_MEGAMENU_TEXTDOMAIN ),
				'menu_title' => $menu_title,
				'capability' => 'manage_options',
				'menu_slug' => 'cr-menu-addons',
				'function' => array( __CLASS__, 'addons' ),
			);

			CR_Megamenu_Init_Admin_Menu::add( $menu, 'edit.php?post_type=cr_megamenu_profile' );
		}
	}

	/**
	 * Render settings screen.
	 *
	 * @return  void
	 */
	public static function settings() {
		// Instantiate settings class
		// CR_Megamenu_Settings::init();
		include CR_MEGAMENU_TPL_PATH . '/settings.php';
	}

	/**
	 * Render addons management screen.
	 *
	 * @return  void
	 */
	public static function addons() {
		// Instantiate product addons class
		CR_Megamenu_Init_Assets::load( array( 'cr-addons-js' ) );
		CR_Megamenu_Product_Addons::init( CR_MEGAMENU_IDENTIFIED_NAME );
	}

	/**
	 * Render about-us screen.
	 *
	 * @return void
	 */
	public static function about_us() {
		// Load assets
		CR_Megamenu_Init_Assets::load( array( 'cr-mm-bootstrap3-css', 'cr-bootstrap3-js' ) );
		// Load template
		include CR_MEGAMENU_TPL_PATH . '/about-us.php';
	}

}
