<?php

/**
 * @version    $Id$
 * @package    CR MegaMenu
 * @author     Webinane Team <support@Webinane.com>
 * @copyright  Copyright (C) 2014 Webinane.com All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 *
 * Websites: http://www.Webinane.com
 * Technical Support:  Feedback - http://www.Webinane.com
 */

/**
 * CR MegaMenu plugin initialization.
 *
 * @package  CR_Megamenu
 * @since	1.0.0
 */
class CR_Megamenu_Plugin {

	/**
	 * Initialize CR Sample plugin.
	 *
	 * @return  void
	 */
	public static function init() {
		global $wp_widget_factory, $mega_menu, $cr_megamenu_element, $cr_megamenu_widgets;

		// Init neccessary CR Library classes
		CR_Megamenu_Init_Admin_Menu::hook();
		// Load required assets
		CR_Megamenu_Assets::init();

		CR_Megamenu_Init_Assets ::hook();
		// Load update simulator
		CR_Megamenu_Update_Simulator::hook();

		// Init element
		$cr_megamenu_element = new CR_Megamenu_Element();
		$cr_megamenu_element->init();

		//
		if ( is_admin() ) {
			$mega_menu = new CR_Megamenu_Core_Backend();

			// Insert Webinane banner
			global $pagenow;
			$post_type = '';
			if ( ( $pagenow == 'post-new.php' ) && ( isset( $_REQUEST['post_type'] ) ) ) {
				$post_type = $_REQUEST['post_type'];
			} elseif ( ( $pagenow == 'post.php' ) && ( isset( $_REQUEST['post'] ) ) ) {
				$post_type = get_post_type( $_REQUEST['post'] );
			}
		} else {
			// Process menu frontend
			$frontend = new CR_Megamenu_Core_Frontend();
			$frontend->apply_megamenu();
		}

		// Register 'admin_menu' action
		add_action( 'admin_menu', array( __CLASS__, 'admin_menu' ) );

		// Register 'cr_mm_installed_product' filter
		add_filter( 'cr_mm_installed_product', array( __CLASS__, 'register_product' ) );

		// Initialize widget support
		$cr_megamenu_widgets = !empty( $cr_megamenu_widgets ) ? $cr_megamenu_widgets : CR_Megamenu_Helpers_Functions::widgets();
	}

	/**
	 * Do 'admin_menu' action.
	 *
	 * @return  void
	 */
	public static function admin_menu() {
		// Register admin menu
		CR_Megamenu_Admin_Menu::init();
	}

	/**
	 * Apply 'cr_mm_installed_product' filter.
	 *
	 * @param   array  $plugins  Array of installed Webinane product.
	 *
	 * @return  array
	 */
	public static function register_product( $plugins ) {
		// Register product identification
		$plugins[] = CR_MEGAMENU_IDENTIFIED_NAME;

		return $plugins;
	}

}
