<?php
/**
 * @version    $Id$
 * @package    CR MegaMenu
 * @author     Webinane Team <support@Webinane.com>
 * @copyright  Copyright (C) 2014 Webinane.com All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 *
 * Websites: http://www.Webinane.com
 * Technical Support:  Feedback - http://www.Webinane.com
 */

/**
 * WordPress update simulator.
 *
 * @package  CR_Megamenu
 * @since    1.0.0
 */
class CR_Megamenu_Update_Simulator {
	/**
	 * Hook into WordPress.
	 *
	 * @return  void
	 */
	public static function hook() {
		// Register necessary filters
		add_filter( 'site_transient_update_plugins', array( __CLASS__, 'site_transient_update_plugins' ) );
	}

	/**
	 * Set site transient to fake update information.
	 *
	 * @param   array  $value  The value of update_plugins site transient.
	 *
	 * @return  mixed
	 */
	public static function site_transient_update_plugins( $value ) {
		// Get update simulator settings
		$settings = CR_Megamenu_Settings::get();

		if ( crazyblog_set($settings, 'update-simulator') ) {
			$update = array();

			// Preset value
			if ( ! is_object( $value ) ) {
				$value = (object) array( 'response' => array() );
			}

			foreach ( array( 'pagebuilder', 'uniform', 'poweradmin' ) as $plugin ) {
				// Simulate update info for configured plugins
				if ( ! empty( $settings[ "cr-{$plugin}-version" ] ) && ! empty( $settings[ "cr-{$plugin}-link" ] ) ) {
					// Simulate update available only if plugin is installed
					if ( @is_file( WP_PLUGIN_DIR . '/' . $settings[ "cr-{$plugin}-file" ] ) ) {
						// Make simulated version is really newer
						$current = CR_Megamenu_Product_Info::get( WP_PLUGIN_DIR . '/' . $settings[ "cr-{$plugin}-file" ] );

						if ( version_compare( $current['Version'], $settings[ "cr-{$plugin}-version" ], '<' ) ) {
							$value->response[ $settings[ "cr-{$plugin}-file" ] ] = (object) array(
								'id'          => 0,
								'slug'        => "cr-{$plugin}",
								'new_version' => $settings[ "cr-{$plugin}-version" ],
								'url'         => "https://wordpress.org/plugins/cr-{$plugin}/",
								'package'     => $settings[ "cr-{$plugin}-link" ],
							);
						}
					}
				}
			}
		}

		return $value;
	}
}
