<?php
if ( !class_exists( 'CR_Megamenu_Carousal' ) ) {

	/**
	 * Create Text element
	 *
	 * @package  CR MegaMenu Shortcodes
	 * @since	1.0.0
	 */
	class CR_Megamenu_Carousal extends CR_Megamenu_Shortcode_Element {

		static $counter = 0;

		/**
		 * Constructor
		 *
		 * @return  void
		 */
		public function __construct() {
			parent::__construct();
		}

		/**
		 * Configure shortcode.
		 *
		 * @return  void
		 */
		function element_config() {
			$this->config['shortcode'] = strtolower( __CLASS__ );
			$this->config['name'] = __( 'Carousal', CR_MEGAMENU_TEXTDOMAIN );
			$this->config['cat'] = __( 'Webinane', CR_MEGAMENU_TEXTDOMAIN );
			$this->config['icon'] = 'cr-icon-text';
			$this->config['description'] = __( 'Category Based Carousal', CR_MEGAMENU_TEXTDOMAIN );

			// Define exception for this shortcode
			$this->config['exception'] = array(
				'default_content' => __( 'Carousal', CR_MEGAMENU_TEXTDOMAIN ),
				'admin_assets' => array(
					crazyblog_URI . 'assets/js/owl.carousel.min.js'
				),
				'frontend_assets' => array(
					crazyblog_URI . 'assets/css/style.css'
				),
			);

			// Use Ajax to speed up element settings modal loading speed
			$this->config['edit_using_ajax'] = true;
		}

		/**
		 * Define shortcode settings.
		 *
		 * @return  void
		 */
		function element_items() {
			$this->items = array(
				'content' => array(
					array(
						'name' => __( 'Select Category', CR_MEGAMENU_TEXTDOMAIN ),
						'id' => 'cate',
						'type' => 'select',
						'class' => 'input-sm',
						'std' => __( '', CR_MEGAMENU_TEXTDOMAIN ),
						'options' => (function_exists( 'crazyblog_get_categories' )) ? crazyblog_get_categories( array( 'taxonomy' => 'category', 'hide_empty' => true ), true ) : array(),
						'role' => 'dropdown',
						'tooltip' => __( 'Select the category that you want to display', CR_MEGAMENU_TEXTDOMAIN )
					),
					array(
						'name' => __( 'Number', CR_MEGAMENU_TEXTDOMAIN ),
						'id' => 'number',
						'type' => 'text_field',
						'class' => 'input-sm',
						'std' => __( '', CR_MEGAMENU_TEXTDOMAIN ),
						'role' => 'title',
						'tooltip' => __( 'Enter the number of post to show', CR_MEGAMENU_TEXTDOMAIN )
					),
					array(
						'name' => __( 'Order', CR_MEGAMENU_TEXTDOMAIN ),
						'id' => 'order',
						'type' => 'select',
						'class' => 'input-sm',
						'std' => __( '', CR_MEGAMENU_TEXTDOMAIN ),
						'options' => array(
							'ASC' => esc_html__( 'Ascending', 'crazyblog' ),
							'DESC' => esc_html__( 'Descending', 'crazyblog' )
						),
						'role' => 'dropdown',
						'tooltip' => __( 'Select sorting order ascending or descending for posts listing', CR_MEGAMENU_TEXTDOMAIN )
					),
					array(
						'name' => __( 'Order By', CR_MEGAMENU_TEXTDOMAIN ),
						'id' => 'orderby',
						'type' => 'select',
						'class' => 'input-sm',
						'std' => __( '', CR_MEGAMENU_TEXTDOMAIN ),
						'options' => array(
							'date' => esc_html__( 'Date', 'crazyblog' ),
							'title' => esc_html__( 'Title', 'crazyblog' ),
							'name' => esc_html__( 'Name', 'crazyblog' ),
							'author' => esc_html__( 'Author', 'crazyblog' ),
							'comment_count' => esc_html__( 'Comment Count', 'crazyblog' ),
							'random' => esc_html__( 'Random', 'crazyblog' )
						),
						'role' => 'dropdown',
						'tooltip' => __( 'Select order by method for posts listing', CR_MEGAMENU_TEXTDOMAIN )
					)
				)
			);
		}

		/**
		 * Generate HTML code from shortcode content.
		 *
		 * @param   array $atts Shortcode attributes.
		 * @param   string $content Current content.
		 *
		 * @return  string
		 */
		function element_shortcode_full( $atts = null, $content = null ) {
			$arr_params = shortcode_atts( $this->config['params'], $atts );
			extract( $arr_params );
			$random_id = CR_Megamenu_Helpers_Common::random_string();
			if ( !empty( $content ) ) {
				$content = CR_Megamenu_Helpers_Shortcode::remove_autop( $content, true );
			}

			ob_start();
			$args = array(
				'post_type' => 'post',
				'post_status' => 'publish',
				'orderby' => $orderby,
				'order' => $order,
				'showposts' => $number,
				'category_name' => $cate,
			);
			$query = new WP_Query( $args );
			if ( $query->have_posts() ) {
				wp_enqueue_script( 'crazyblog_df-owl', crazyblog_URI . 'assets/js/owl.carousel.min.js', array( 'jquery' ), '', true );
				$counter = 0;
				echo '<div class="mega-carousel mc' . self::$counter . '">';
				while ( $query->have_posts() ) {
					$query->the_post();
					if ( has_post_thumbnail() ):
						?>
						<div class="mega-post">
							<div class="post-thumb">
								<a href="<?php the_permalink() ?>" title="<?php the_title() ?>">
									<?php the_post_thumbnail( 'thumbnail' ) ?>
								</a>
							</div>
							<h4>
								<a href="<?php the_permalink() ?>" title="<?php the_title() ?>"><?php the_title() ?></a>
							</h4>
							<span><?php echo get_the_date( get_option( 'post_format' ) ); ?></span>
						</div>
						<?php
						$counter++;
					endif;
				}
				wp_reset_postdata();
				echo '</div>';
				$loop = ($counter > 0) ? 'true' : 'false';
				?>
				<script type="text/javascript">
					jQuery(document).ready(function ($) {
						"use strict";
						$('div.mega-carousel.<?php echo esc_js( 'mc' . self::$counter ) ?>').owlCarousel({
							autoplay: true,
							autoplayTimeout: 2500,
							smartSpeed: 2000,
							autoplayHoverPause: true,
							loop: <?php echo esc_js( $loop ) ?>,
							dots: false,
							nav: true,
							margin: 10,
							mouseDrag: true,
							autoHeight: true,
							items: 3
						});
					});
				</script>
				<?php
			}
			self::$counter++;
			$html = ob_get_contents();
			ob_end_clean();
			return $this->element_wrapper( $html, array() );
		}

	}

}
